pro outputalbedomap, Lat, Lon, AlbedoMap, outHDFFileName, NGridX, NGridY

;*************************************************************************
; Name: outpoutalbedomap
;
; Purpose:
; outputAlbedoMap.pro creates a new HDF file and outputs the lat/lon arrays,
;   as well as the derived ecosystem map to this new HDF file.  Local and
;   global attributes are added as metadata.
;
;
; Input: 
;    Lat                Float Array: Latitude array
;    Lon                Float Array: Longitude array
;    AlbedoMap          Float Array: Derived Albedo map
;    outHDFFileName     String     : Name of the output HDF file
;    NGridX             Integer    : Number of Longitude grid points
;    NGridY             Integer    : Number of Latitude  grid points
; 
; Output:
;    none
;
; Required Programs:
;    none
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************

;***********************************************************
;Determine the Xdimension and Ydimensions and name them:
;***********************************************************
dims = size(lon,/dimensions)
xdim = dims(0)
ydim = dims(1)
xname = 'XDim'
yname = 'YDim'


;***********************************************************
;Create the hdf file:
;***********************************************************
outHDFFileID = HDF_SD_START(outHDFFileName,/CREATE)


;***********************************************************
;Write the global attributes:
;***********************************************************
title        = 'Global Albedo map generated from the 6 bands of the MOD12Q1/MOD43 data.'
creationDate = Systime()
createdBy    = 'Eric Moody (eric.moody@gsfc.nasa.gov)
scienceTeam  = 'NASA/GSFC Cloud Retrieval Group'
sensor       = 'Terra'
dataProduct  = 'MOD06OD'

HDF_SD_ATTRSET, outHDFFileID, 'Title', title, STRLEN(title)
HDF_SD_ATTRSET, outHDFFileID, 'Number of Longitude Points', NGridX, /INT
HDF_SD_ATTRSET, outHDFFileID, 'Number of Latitude Points' , NGridY, /INT
HDF_SD_ATTRSET, outHDFFileID, 'CreationDate', creationDate, STRLEN(creationDate)
HDF_SD_ATTRSET, outHDFFileID, 'CreatedBy', createdBy, STRLEN(createdBy)
HDF_SD_ATTRSET, outHDFFileID, 'ScienceTeam', scienceTeam, STRLEN(scienceTeam)
HDF_SD_ATTRSET, outHDFFileID, 'Platform', sensor, STRLEN(sensor)
HDF_SD_ATTRSET, outHDFFileID, 'AncillaryProductFor', dataProduct, STRLEN(dataProduct)



;***********************************************************
;Create the Lat SDS:
;***********************************************************
;Create the Lat SDS, and rename the dimensions:
LatID = HDF_SD_CREATE(outHDFFileID, 'Latitude', [xdim,ydim], /FLOAT)
dimid = HDF_SD_DIMGETID(LatID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(LatID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the Lat local attributes:
Long_Name = 'Geodetic Latitude'
units = "degrees_north" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, LatID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, LatID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, LatID, '_FillValue', [-999.9], /FLOAT
HDF_SD_ATTRSET, LatID, 'valid_range', [-90.0, 90.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, LatID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the Lat SDS:
HDF_SD_ADDDATA, LatID, Lat

;End access to the Lat SDS:
HDF_SD_ENDACCESS, LatID


;***********************************************************
;Create the Lon SDS:
;***********************************************************
;Create the Lon SDS, and rename the dimensions:
LonID = HDF_SD_CREATE(outHDFFileID, 'Longitude', [xdim,ydim], /FLOAT)
dimid = HDF_SD_DIMGETID(LonID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(LonID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the Lon local attributes:
Long_Name = 'Geodetic Longitude'
units = "degrees_east" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, LonID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, LonID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, LonID, '_FillValue', [-999.9], /FLOAT
HDF_SD_ATTRSET, LonID, 'valid_range', [-180.0, 180.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, LonID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the Lon SDS:
HDF_SD_ADDDATA, LonID, Lon

;End access to the Lon SDS:
HDF_SD_ENDACCESS, LonID


;***********************************************************
;Create the Albedo map SDS:
;***********************************************************
;Create the Albedo map, and rename the dimensions:
AlbID = HDF_SD_CREATE(outHDFFileID, 'Albedo_Map', [xdim,ydim,6], /FLOAT)
mdname = 'Band'
dimid = HDF_SD_DIMGETID(AlbID,2)
        HDF_SD_DIMSET, dimid, name=mdname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(AlbID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(AlbID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the Albedo Map local attributes:
Long_Name = 'Albedo map derived from MOD12Q1/MOD43B3 product.'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, AlbID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, AlbID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, AlbID, '_FillValue', [-999.9], /FLOAT
HDF_SD_ATTRSET, AlbID, 'valid_range', [0., 1.], /FLOAT
HDF_SD_ATTRSET, AlbID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, AlbID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, AlbID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, AlbID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the Albedo Map array:
HDF_SD_ADDDATA, AlbID, AlbedoMap

;End access to the Albedo Map SDS:
HDF_SD_ENDACCESS, AlbID


;***********************************************************
;End access to the HDF file:
;***********************************************************
HDF_SD_END, outHDFFileID


end
