PRO anci


;*************************************************************************
; Name: anci
;
; Purpose:
;   This rountine is the main driver to plot data from the MOD06OD Ancillary
;    HDF file, which is produced only when MOD06OD is run locally. Additionally,
;    this code will read lat/lon information from the supplied MOD03 file.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   Input_Path     :  Directory where the ancillary file is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_anci.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names. 
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')


;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')

;*************************************************************************
; Define the file that contain the Ancillary data, including path.  
;*************************************************************************
;Define the path where the Ancillary HDF files reside:
AnciPath = GETENV('Input_Path')
 
;Define the Anci File Name:
Ancifilename = StrArr(1)
Ancifilename[0] = AnciPath+'MOD06OD_QC.A'+Year+Day+'.'+Time+'.txt'
print, 'Processing ',Ancifilename


;*************************************************************************
; Define the MOD03 files that contain the Geolocation file, including path,
; that correspond to the granules defined above.  Ex.
;*************************************************************************
;Geo Path:
GeoPath = GETENV('Input_Path_2')

;Define the filespec
filespec = GeoPath+'MOD03.A'+year+day+'.'+Time+'*.hdf'

;Find the file:
Geofilename = StrArr(1)
result = FINDFILE(filespec)
;Store the result in the Geo array:
Geofilename[0] = strcompress(result[0])
print, 'Geofile',GeoPath,Geofilename

;*************************************************************************
; Define the Ancillary SDSs to plot.  If the SDS is to be plotted, set 
; the value to 1, if not, set to 0.
;*************************************************************************
numSDS      = 7
PlotAnci    = IntArr(numSDS)
PlotAnci[0] = 1 ; Total Precipitable Water
PlotAnci[1] = 1 ; Cloud Top Height
PlotAnci[2] = 1 ; Cloud Top Temperature
PlotAnci[3] = 1 ; Temperature Profile
PlotAnci[4] = 1 ; Surface Temperature Over Land
PlotAnci[5] = 1 ; Surface Temperature Over Ocean
PlotAnci[6] = 1 ; Surface Albedo

;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
AnciOutName    = StrArr(numSDS)
AnciOutName[0] = 'Ttl_Prcip_Wtr'
AnciOutName[1] = 'Cld_Top_Hght'
AnciOutName[2] = 'Cld_Top_Temp'
AnciOutName[3] = 'Temp_Profile'
AnciOutName[4] = 'Surf_Temp_Lnd'
AnciOutName[5] = 'Surf_Temp_Ocn'
AnciOutName[6] = 'Albedo'

;*************************************************************************
; Define the SDS limits, as [min, max]:
;*************************************************************************
AnciSDSLimits      = FltArr(numSDS,2)
AnciSDSLimits[0,0] = 0.    ;Ttl_Precip_Wtr, min
AnciSDSLimits[0,1] = 7.5   ;Ttl_Precip_Wtr, max
AnciSDSLimits[1,0] = 300.  ;Cld_Top_Hght, min
AnciSDSLimits[1,1] = 1000. ;Cld_Top_Hght, max
AnciSDSLimits[2,0] = 200.  ;Cld_Top_Temp, min
AnciSDSLimits[2,1] = 300.  ;Cld_Top_Temp, max
AnciSDSLimits[3,0] = 200.  ;Temp_Profile, min
AnciSDSLimits[3,1] = 300.  ;Temp_Profile, max
AnciSDSLimits[4,0] = 275.  ;Surf_Temp_Land, min
AnciSDSLimits[4,1] = 310.  ;Surf_Temp_Land, max
AnciSDSLimits[5,0] = 275.  ;Surf_Temp_Ocn, min
AnciSDSLimits[5,1] = 310.  ;Surf_Temp_Ocn, max
AnciSDSLimits[6,0] = 0.    ;Albedo, min
AnciSDSLimits[6,1] = 0.5   ;Albedo, max


;*************************************************************************
; Choose the number of levels to be included on the color bar:
;*************************************************************************
Num_CB_Levels    = IntArr(numSDS)
Num_CB_Levels[0] = 5 ;Ttl_Precip_Wtr 
Num_CB_Levels[1] = 5 ;Cld_Top_Hght 
Num_CB_Levels[2] = 5 ;Cld_Top_Temp
Num_CB_Levels[3] = 5 ;Temp_Profile
Num_CB_Levels[4] = 5 ;Surf_Temp_Land
Num_CB_Levels[5] = 5 ;Surf_Temp_Ocn
Num_CB_Levels[6] = 5 ;Albedo





;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************



;*************************************************************************
; Definition of the names of the Ancillary SDS as defined in the HDF file. 
;*************************************************************************
AnciSDSName    = StrArr(numSDS)
AnciSDSName[0] = 'Precipitable_Water_above_Cloud'
AnciSDSName[1] = 'Cloud_Top_Pressure'
AnciSDSName[2] = 'Cloud_Top_Temperature'
AnciSDSName[3] = 'Mean_Temperature_above_Cloud'
AnciSDSName[4] = 'Land_Surface_Temperature'
AnciSDSName[5] = 'Ocean_Surface_Temperature'
AnciSDSName[6] = 'Surface_Albedo'

;*************************************************************************
; Loop over the SDSs, except Surface Albedo, plotting only the desired ones.
;*************************************************************************
for icnt = 0, numSDS-2 do begin

   ;*************************************************************************
   ; Define the name of the output image file, including path:
   ;*************************************************************************
   AnciOutFileName = output_dir+AnciOutName[icnt]+'.'+Year+'.'+Day+'.'+Time+'.ps'

   ;*************************************************************************
   ; Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   ;titlestring = 'Year 2000, Day 110, combined granules 0855 and 0900'
   titlestring = AnciSDSName[icnt]+', Year '+Year+', Day '+Day+', '+Time

   ;*************************************************************************
   ;If you would like to specify the lat/lons to plot, please specify them
   ;   here.  This option is to be used if you want to specify a lat/lon box
   ;   of the granule(s) to plot.  The format is as follows:
   ;   limits=[NorthBound,WestBound,SouthBound,EastBound]
   ;If you want the program to compute the bounds, please set limits = 0 
   ;*************************************************************************

   ;*************************************************************************
   ;Call the program, bearing in mind that only the postscript output is 
   ;*************************************************************************
   ;Since these are two dim, set multidim_choice to 0:
   multidim_choice = 0
   ;Test to see if this SDS should be plotted:
   print, ''
   IF (PlotAnci[icnt] eq 1) then begin
      ;Call the plotting code:
      print, 'Plotting ',AnciSDSName[icnt]
      SDS_limits = [AnciSDSLimits[icnt,0],AnciSDSLimits[icnt,1]]
      plot_anci, Ancifilename, Geofilename, AnciSDSName[icnt], $
                   AnciOutFileName, titlestring, SDS_limits,     $
                   Num_CB_Levels[icnt],                          $
	           multidim_choice, /ps, /notation
   ENDIF ELSE BEGIN
      print, 'Skipping ',AnciSDSName[icnt]
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
endfor


;*************************************************************************
; Plot Surface Albedo,if desired.
;*************************************************************************
icnt = numSDS-1
IF (PlotAnci[icnt] eq 1) then begin

   band = strarr(6)
   band(0) = '0.659'
   band(1) = '0.865'
   band(2) = '1.240'
   band(3) = '1.640'
   band(4) = '2.130'
   band(5) = '3.750'

   ;*************************************************************************
   ;Loop over the bands:
   ;*************************************************************************
   for jcnt = 0, 5 do begin

      ;**********************************************************************
      ; Define the name of the output image file, including path:
      ;**********************************************************************
      strjcnt = strcompress(string(jcnt+1),/REMOVE_ALL)
      AnciOutFileName = output_dir + AnciOutName[icnt] + '_' + band[jcnt] + $
                        '.' + Year + '.' + Day + '.' + Time + '.ps'

      ;**********************************************************************
      ; Add a title to the plot if desired. Ex. titlestring ='Title'
      ;**********************************************************************
      ;titlestring = 'Year 2000, Day 110, combined granules 0855 and 0900'
      titlestring = AnciSDSName[icnt] + ', ' + band[jcnt] +' micron, ' + strjcnt + ', Year ' + Year + $
                    ', Day ' + Day + ', ' + Time

      ;**********************************************************************
      ;Call the program, bearing in mind that only the postscript output is 
      ; available.
      ;**********************************************************************
      ;Set multidim_choice to the jcnt:
      multidim_choice = jcnt
      ;Call the plotting code:
      print, ''
      print, 'Plotting ',AnciSDSName[icnt],jcnt
      SDS_limits = [AnciSDSLimits[icnt,0],AnciSDSLimits[icnt,1]]
      plot_anci, Ancifilename, Geofilename, AnciSDSName[icnt], $
                   AnciOutFileName, titlestring, SDS_limits,     $
                   Num_CB_Levels[icnt],                          $
	           multidim_choice, /ps, /notation

   ;*************************************************************************
   ;End the looping:
   ;*************************************************************************
   endfor

;End the if loop:
endif


END
