pro outputl2qabits, Lat, Lon, QAFlags, outHDFFileName, day, year, time

;*************************************************************************
; Name: outputl2qabits
;
; Purpose:
; outputl2qabits.pro creates a new HDF file and outputs the lat/lon arrays,
;   as well as integer arrays containing the individual cloud mask test results.
;   Local and global attributes are added as metadata.
;
;
; Input: 
;    Lat                Float Array: Latitude array
;    Lon                Float Array: Longitude array
;    QAFlags            Int Array  : L2QA Test Results
;    outHDFFileName     String     : Name of the output HDF file
;    day                String     : Julian Day
;    year               String     : Year
;    time               String     : Time as HHMM (H=hour, M=minute)
; 
; Output:
;    none
;
; Required Programs:
;    none
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;***********************************************************
;Create the hdf file:
;***********************************************************
outHDFFileID = HDF_SD_START(outHDFFileName,/CREATE)


;***********************************************************
;Write the global attributes:
;***********************************************************
title        = 'Level 2, MOD06, Quality Assurance Flags, 1KM'
creationDate = Systime()
createdBy    = 'Eric Moody (eric.moody@gsfc.nasa.gov)
scienceTeam  = 'NASA/GSFC Cloud Retrieval Group'
sensor       = 'Terra'
dataProduct  = 'MOD06OD'

HDF_SD_ATTRSET, outHDFFileID, 'Title', title, STRLEN(title)
HDF_SD_ATTRSET, outHDFFileID, 'JulianDay', day, STRLEN(day)
HDF_SD_ATTRSET, outHDFFileID, 'Year', year, STRLEN(year)
HDF_SD_ATTRSET, outHDFFileID, 'Time (HHMM)', time, STRLEN(time)
HDF_SD_ATTRSET, outHDFFileID, 'CreationDate', creationDate, STRLEN(creationDate)
HDF_SD_ATTRSET, outHDFFileID, 'CreatedBy', createdBy, STRLEN(createdBy)
HDF_SD_ATTRSET, outHDFFileID, 'ScienceTeam', scienceTeam, STRLEN(scienceTeam)
HDF_SD_ATTRSET, outHDFFileID, 'Platform', sensor, STRLEN(sensor)
HDF_SD_ATTRSET, outHDFFileID, 'AncillaryProductFor', dataProduct, STRLEN(dataProduct)


;***********************************************************
;Determine the 5km Xdimension and Ydimensions and name them:
;***********************************************************
dims = size(Lat,/dimensions)
xdim = dims(0)
ydim = dims(1)
xname = 'Cell_Along_Swath_5km'
yname = 'Cell_Across_Swath_5km'


;***********************************************************
;Create the Lat SDS:
;***********************************************************
;Create the Lat SDS, and rename the dimensions:
LatID = HDF_SD_CREATE(outHDFFileID, 'Latitude', [xdim,ydim], /FLOAT)
dimid = HDF_SD_DIMGETID(LatID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(LatID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the Lat local attributes:
Long_Name = 'Geodetic Latitude'
units = "degrees_north" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, LatID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, LatID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, LatID, '_FillValue', [-999.9], /FLOAT
HDF_SD_ATTRSET, LatID, 'valid_range', [-90.0, 90.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, LatID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the Lat SDS:
HDF_SD_ADDDATA, LatID, Lat

;End access to the Lat SDS:
HDF_SD_ENDACCESS, LatID


;***********************************************************
;Create the Lon SDS:
;***********************************************************
;Create the Lon SDS, and rename the dimensions:
LonID = HDF_SD_CREATE(outHDFFileID, 'Longitude', [xdim,ydim], /FLOAT)
dimid = HDF_SD_DIMGETID(LonID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(LonID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the Lon local attributes:
Long_Name = 'Geodetic Longitude'
units = "degrees_east" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, LonID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, LonID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, LonID, '_FillValue', [-999.9], /FLOAT
HDF_SD_ATTRSET, LonID, 'valid_range', [-180.0, 180.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, LonID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the Lon SDS:
HDF_SD_ADDDATA, LonID, Lon

;End access to the Lon SDS:
HDF_SD_ENDACCESS, LonID


;***********************************************************
;Determine the 1km Xdimension and Ydimensions and name them:
;***********************************************************
dims = size(QAFlags,/dimensions)
xdim = dims(0)
ydim = dims(1)
xname = 'Cell_Along_Swath_1km'
yname = 'Cell_Across_Swath_1km'
print, '1km x,y',xdim,ydim


;***********************************************************
;Create the Opt Thick Gen QA SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Opt_Thick_Gen_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Optical Thickness General QA'
units = 'none'
ParmType = 'MODIS Input'
GeoPointer = 'Internal geolocation arrays'
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 1], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1], /INT
strvalue = 'Not Useful'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Useful'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,0]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Opt Thick Conf QA SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Opt_Thick_Conf_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Optical Thickness Confidence QA'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'Bad'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Marginal'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'Good'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Very Good'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,1]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Optical Thickness out-of-bounds SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Opt_Thick_Out_of_Bounds', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Optical Thickness out-of-bounds'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'Within Bound (OT<=100)'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = '100 < OT < 150'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'OT > 150'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'OT <= 0'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,2]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Effective Radius General QA SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Eff_Rad_Gen_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Effective Radius General QA'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 1], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1], /INT
strvalue = 'Not Useful'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Useful'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,3]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Effective Radius Confidence QA SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Eff_Rad_Conf_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Effective Radius Confidence QA'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'Bad'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Marginal'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'Good'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Very Good'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,4]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Liquid Water Path General QA SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Liq_Wat_Path_Gen_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Liquid Water Path General QA'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 1], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1], /INT
strvalue = 'Not Useful'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Useful'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,5]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Liquid Water Path Confidence QA SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Liq_Wat_Path_Conf_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Liquid Water Path Confidence QA'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'Bad'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Marginal'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'Good'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Very Good'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,6]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Cloud Phase Determination (SWIR) SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Cloud_Phase_Det_SWIR', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Cloud Phase Determination, SWIR'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 4], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3,4], /INT
strvalue = 'Fill Value'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Clear'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Water'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Ice'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Mixed/Undet.'
HDF_SD_ATTRSET, SDSID, 'annot_value_4', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,7]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Cloud Phase used in retrieval processing path SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Cloud_Phase_Retr_Proc_Path', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Cloud Phase used in retrieval processing path'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 5], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3,4,5], /INT
strvalue = 'Cld Msk Undeter.'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Dec. Tree Stop'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Water'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Ice'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
strvalue = 'Cld, Uncertain'
HDF_SD_ATTRSET, SDSID, 'annot_value_4', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Mixed'
HDF_SD_ATTRSET, SDSID, 'annot_value_5', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,8]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Retrieval Outcome SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Retrieval_Outcome', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Retrieval Outcome'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 1], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1], /INT
strvalue = 'No attempt, unsuccess.'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Successful'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,9]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Rayleigh Correction SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Rayleigh_Correction', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Rayleigh Correction'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 1], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1], /INT
strvalue = 'No'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Yes'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,10]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Water Vapor Correction SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Water_Vap_Corr', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Water Vapor Correction'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 1], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1], /INT
strvalue = 'No'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Yes'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,11]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Band Used for Optical Thickness Retrieval SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Band_Used_Opt_Thck_Retr', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Band Used for Optical Thickness Retrieval'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'Not Retrieved'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = '0.645 mic(land)'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = '0.858 mic(water)'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = '1.24 mic(snow/ice)'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,12]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Total Precipital Water SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Ttl_Precip_Wtr_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Total Precipital Water'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'NCEP GDAS'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'DAO'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'MOD07 - IR'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Clear or Undeter.'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,13]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Cloud Top Height SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Cld_Top_Hght_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Cloud Top Height'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'MOD06 (Menzel)'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'DAO'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'Other'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Clear or Undeter.'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,14]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Temperature Profile SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Temp_Profile_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Temperature Profile'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'NCEP GDAS'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'DAO'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'AIRS/AMSU/HSB'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Clear or Undeter.'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,15]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Surface Temperature Over Land SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Surf_Temp_Land_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Surface Temperature Over Land'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'NCEP GDAS'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'DAO'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'MOD11'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Clear or Undeter.'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,16]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Surface Temperature Over Ocean SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Surf_Temp_Ocn_QA', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Surface Temperature Over Ocean'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'NCEP Reynolds SST'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'DAO'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'MOD28'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Clear or Undeter.'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,17]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the BRDF/Albedo SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'BRDF_Albedo', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'BRDF, Albedo'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'CERES/SARB'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'MOD43/MOD12 Seasonal'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'MOD43'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Clear or Undeter.'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,18]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;Create the Ozone Profiles SDS:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'Ozone_Prof', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Ozone Profiles'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 3], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3], /INT
strvalue = 'TOMS'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'TOVS'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'DAO'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Clear or Undeter.'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,19]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID




;***********************************************************
;End access to the HDF file:
;***********************************************************
HDF_SD_END, outHDFFileID


end
