Function ReadSDS, fileId, varname, $
                  scaleNo=scaleNo, offsetNo=offsetNo, fillNo=fillNo
;+
;.......................................................................
; $Id$
;.......................................................................
; NAME: ReadSDS
;	
;
; PURPOSE:
;        given file id and a variable name, retrieve "calibrated" data 
;        values.
;	
;
; CATEGORY:
;        HDF data reader
;
;
; CALLING SEQUENCE:
;	Result = ReadSDS(fileId, varname)
;
; INPUTS:
;	fileId:	HDF file id number
;       varname: variable name
;
; OPTIONAL INPUTS:
;       scaleNo:  This parameter does not have scale factor attribute;
;                 default assumes that it has.
;       offsetNo: This parameter does not have offset attribute; 
;                 default assumes that it has.
;       fillNo:   This parameter does not have fill value attribute;
;                 default assumes that it has.
;
;
; OUTPUTS:
;       calibrated data in proper physical units
;
;
; USAGE EXAMPLES:
;
; fileId = HDF_SD_START("sample.hdf", /READ)
; variable = ReadSDS(fileId, 'Cloud_Mask')
; HDF_SD_END, fileId
;
;
;
; COMMON BLOCKS:
;	None.
;
; SIDE EFFECTS:
;       AT Launch, the calibration method no longer follow NCSA's
;       HDF convention. It will be: 
;                dataValue = scale_factor * (dataValue-offset)
;.......................................................................
; REVISION HISTORY:
; $Log$
;.......................................................................
; PROGRAMMER:  
;              Jason Li 
;              SM&A Inc | Climate and Radiation Branch
;              NASA Goddard Space Flight Center
;              Greenbelt, Maryland, U.S.A.
;.......................................................................
;-


;... read SDS data:

index = HDF_SD_NAMETOINDEX(fileId, varname)
sdsid = HDF_SD_SELECT(fileId, index)
HDF_SD_GETDATA, sdsid, dataValue
HDF_SD_ENDACCESS, sdsid


;... read attributes:

scale_factor = 1.0
IF NOT Keyword_Set(scaleNo) THEN BEGIN
   scaleId = HDF_SD_ATTRFIND(sdsid,"scale_factor")
   IF scaleId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, scaleId, DATA=scale_factor
      scale_factor = scale_factor[0]
   ENDIF
ENDIF

offset = 0.0
IF NOT Keyword_Set(offsetNo) THEN BEGIN
   offsetId = HDF_SD_ATTRFIND(sdsid,"add_offset")
   IF offsetId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, offsetId, DATA=offset
      offset = offset[0]
   ENDIF
ENDIF

fillId = -1
IF NOT Keyword_Set(fillNo) THEN BEGIN
   fillId = HDF_SD_ATTRFIND(sdsid,"_FillValue")
   IF fillId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, fillId, DATA=fillValue
      fillValue = fillValue[0]
   ENDIF
ENDIF

;... calibrate data by applying scale factor and offset if necessary:

count = 0
IF fillId NE -1 THEN index = Where(dataValue ne fillValue, count)


;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
; AT Launch, it should be: dataValue = scale_factor * (dataValue-offset)
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

IF count gt 0 THEN BEGIN
   IF scale_factor ne 1.0 THEN BEGIN
      dataValue = float(dataValue)
      dataValue[index] = dataValue[index] * scale_factor
   ENDIF
   IF offset[0] ne 0.0 THEN $
      dataValue[index] = dataValue[index] + offset
ENDIF

Return, dataValue

END ;===================================================================
